@@ -13,12 +13,13 @@
 #
 # COPYRIGHT
 #   Copyright (C) 2000-2009 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 2009 Andrew Ford.  All Rights Reserved.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: POM.pm 57 2009-03-20 12:33:18Z ford $
+#   $Id: POM.pm 89 2013-05-30 07:41:52Z ford $
 #
 #========================================================================
 
@@ -27,28 +28,27 @@ package Pod::POM;
 require 5.004;
 
 use strict;
+
 use Pod::POM::Constants qw( :all );
 use Pod::POM::Nodes;
 use Pod::POM::View::Pod;
 
-use vars qw( $VERSION $DEBUG $ERROR $ROOT $TEXTSEQ $DEFAULT_VIEW );
-use base qw( Exporter );
+use parent qw( Exporter );
 
-$VERSION = '0.23';
-$DEBUG   = 0 unless defined $DEBUG;
-$ROOT    = 'Pod::POM::Node::Pod';               # root node class
-$TEXTSEQ = 'Pod::POM::Node::Sequence';          # text sequence class
-$DEFAULT_VIEW = 'Pod::POM::View::Pod';          # default view class
+our $VERSION = '0.28';
+our $DEBUG   = 0 unless defined $DEBUG;
+our $ROOT    = 'Pod::POM::Node::Pod';               # root node class
+our $TEXTSEQ = 'Pod::POM::Node::Sequence';          # text sequence class
+our $DEFAULT_VIEW = 'Pod::POM::View::Pod';          # default view class
 
 
 #------------------------------------------------------------------------
 # allow 'meta' to be specified as a load option to activate =meta tags
 #------------------------------------------------------------------------
 
-use vars qw( @EXPORT_FAIL @EXPORT_OK $ALLOW_META );
-@EXPORT_OK   = qw( meta );
-@EXPORT_FAIL = qw( meta );
-$ALLOW_META  = 0;
+our @EXPORT_OK   = qw( meta );
+our @EXPORT_FAIL = qw( meta );
+our $ALLOW_META  = 0;
 
 sub export_fail {
     my $class = shift;
@@ -174,6 +174,18 @@ sub parse_text {
     $$line  = 1;
     $inpod  = 0;
 
+    my @encchunks = split /^(=encoding.*)/m, $text;
+    $text = shift @encchunks;
+    while (@encchunks) {
+        my($encline,$chunk) = splice @encchunks, 0, 2;
+        require Encode;
+        my($encoding) = $encline =~ /^=encoding\s+(\S+)/;
+        Encode::from_to($chunk, $encoding, "utf8");
+        Encode::_utf8_on($chunk);
+        # $text .= "xxx$encline";
+        $text .= $chunk;
+    }
+
 # patch from JJ    
 #    while ($text =~ /(?:(.*?)(\n{2,}))|(.+$)/sg) {
     while ($text =~ /(?:(.*?)((?:\s*\n){2,}))|(.+$)/sg) {
@@ -505,7 +517,7 @@ Pod::POM - POD Object Model
         || die $parser->error();
 
     # parse from a file specified by name or filehandle
-    my $pom = $parser->parse_text($file)
+    my $pom = $parser->parse_file($file)
         || die $parser->error();
 
     # parse from text or file 
@@ -1592,7 +1604,7 @@ Andrew Ford E<lt>A.Ford@ford-mason.co.ukE<gt> (co-maintainer as of 03/2009)
 
 =head1 VERSION
 
-This is version 0.23 of the Pod::POM module.
+This is version 0.28 of the Pod::POM module.
 
 =head1 COPYRIGHT
 
@@ -1618,3 +1630,4 @@ further details:
 
     http://www.cpan.org/modules/by-module/Pod/
 
+=cut
