@@ -15,7 +15,7 @@
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: Node.pm 60 2009-03-20 12:41:35Z ford $
+#   $Id: Node.pm 89 2013-05-30 07:41:52Z ford $
 #
 #========================================================================
 
@@ -64,22 +64,22 @@ use overload
 # 
 # Constructor method.  Returns a new Pod::POM::Node::* object or undef
 # on error.  First argument is the Pod::POM parser object, remaining 
-# arguments are node attributes as specified in %ATTRIBS in derived class
+# arguments are node attributes as specified in @ATTRIBS in derived class
 # package.
 #------------------------------------------------------------------------
 
 sub new {
     my $class = shift;
     my $pom   = shift;
-    my ($type, $attribs, $accept, $key, $value, $default);
+    my ($type, @attribs, $accept);
 
     $type = $NAMES->{ $class };
 
     {
 	no strict qw( refs );
-        $attribs = \%{"$class\::ATTRIBS"} || [ ];
+        @attribs = @{"$class\::ATTRIBS"};
 	$accept  = \@{"$class\::ACCEPT"}  || [ ];
-	unless (defined (%{"$class\::ACCEPT"})) {
+	unless (%{"$class\::ACCEPT"}) {
 	    %{"$class\::ACCEPT"} = ( 
 		map { ( $_ => $NODES->{ $_ } ) } @$accept,
 	    );
@@ -95,9 +95,8 @@ sub new {
     }, $class;
 
     # set attributes from arguments
-    keys %$attribs;	    # reset hash iterator
-    while(my ($key, $default) = each %$attribs) {
-	$value = shift || $default;
+    while(my ($key, $default) = splice(@attribs, 0, 2)) {
+	my $value = shift || $default;
 	return $class->error("$type expected a $key")
 	    unless $value;
 	$self->{ $key } = $value;
@@ -185,7 +184,12 @@ sub present {
     my $type   = $self->{ type };
     my $method = "view_$type";
     DEBUG("presenting method $method to $view\n");
-    return $view->$method($self, @args);
+    my $txt = $view->$method($self, @args);
+    if ($view->can("encode")){
+        return $view->encode($txt);
+    } else {
+        return $txt;
+    }
 }
 
 
@@ -289,7 +293,7 @@ sub dump {
     }
     else {
         no strict 'refs';
-        my @attrs = sort keys %{"*${nodepkg}::ATTRIBS"};
+        my @attrs = sort keys %{{ @{"${nodepkg}::ATTRIBS"} }};
         $output .= ("  " x $depth) . $self->type . "\n";
         foreach my $attr (@attrs) {
             if (my $value = $self->{$attr}) {
@@ -384,9 +388,9 @@ Pod::POM::Node - base class for a POM node
 
     package Pod::POM::Node::Over;
     use base qw( Pod::POM::Node );
-    use vars qw( %ATTRIBS @ACCEPT $EXPECT $ERROR );
+    use vars qw( @ATTRIBS @ACCEPT $EXPECT $ERROR );
 
-    %ATTRIBS =   ( indent => 4 );
+    @ATTRIBS =   ( indent => 4 );
     @ACCEPT  = qw( over item begin for text verbatim );
     $EXPECT  =  q( back );
 
@@ -416,16 +420,16 @@ new node objects.
     my $list = Pod::POM::Node::Over->new();
 
 The characteristics of a node can be specified by defining certain
-variables in the derived class package.  The C<%ATTRIBS> hash can be
+variables in the derived class package.  The C<@ATTRIBS> list can be
 used to denote attributes that the node should accept.  In the case of
 an C<=over> node, for example, an C<indent> attribute can be specified
 which otherwise defaults to 4.
 
     package Pod::POM::Node::Over;
     use base qw( Pod::POM::Node );
-    use vars qw( %ATTRIBS $ERROR );
+    use vars qw( @ATTRIBS $ERROR );
 
-    %ATTRIBS = ( indent => 4 );
+    @ATTRIBS = ( indent => 4 );
 
 The new() method will now expect an argument to set the indent value, 
 or will use 4 as the default if no argument is provided.
@@ -437,9 +441,9 @@ If the default value is undefined then the argument is mandatory.
 
     package Pod::POM::Node::Head1;
     use base qw( Pod::POM::Node );
-    use vars qw( %ATTRIBS $ERROR );
+    use vars qw( @ATTRIBS $ERROR );
 
-    %ATTRIBS = ( title => undef );
+    @ATTRIBS = ( title => undef );
 
     package main;
     my $head = Pod::POM::Node::Head1->new('My Title');
@@ -465,9 +469,9 @@ that are permitted as children of a node.
 
     package Pod::POM::Node::Head1;
     use base qw( Pod::POM::Node );
-    use vars qw( %ATTRIBS @ACCEPT $ERROR );
+    use vars qw( @ATTRIBS @ACCEPT $ERROR );
 
-    %ATTRIBS =   ( title => undef );
+    @ATTRIBS =   ( title => undef );
     @ACCEPT  = qw( head2 over begin for text verbatim );
 
 The add() method can then be called against a node to add a new child
@@ -513,9 +517,9 @@ successful termination.
 
     package Pod::POM::Node::Over;
     use base qw( Pod::POM::Node );
-    use vars qw( %ATTRIBS @ACCEPT $EXPECT $ERROR );
+    use vars qw( @ATTRIBS @ACCEPT $EXPECT $ERROR );
 
-    %ATTRIBS =   ( indent => 4 );
+    @ATTRIBS =   ( indent => 4 );
     @ACCEPT  = qw( over item begin for text verbatim );
     $EXPECT  =  q( back );
 
